"use client"

import type React from "react"

import { useEffect } from "react"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { MessageCircle, Youtube, BookOpen } from "lucide-react"
import { ConnectWalletButton } from "../components/connect-wallet"
import { ViewTaxRewards } from "../components/view-tax-rewards"
import { ViewNFTStatus } from "../components/view-nft-status"
import { motion, useAnimation } from "framer-motion"
import { useInView } from "react-intersection-observer"
import ParticleBackground from "../components/particle-background"
import { BuyTokens } from "../components/buy-tokens"
import { useContent } from "../components/content-provider"
import { TokenLogo } from "../components/token-logo"

// Map icon strings to components
const iconMap: Record<string, any> = {
  MessageCircle,
  Youtube,
  BookOpen,
}

export default function LandingPage() {
  const { content, isLoading } = useContent()

  if (isLoading || !content) {
    return (
      <div className="min-h-screen flex items-center justify-center bg-gradient-to-b from-blue-900 via-indigo-900 to-purple-900">
        <p className="text-white">Loading...</p>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-blue-900 via-indigo-900 to-purple-900">
      <ParticleBackground />
      <header className="container mx-auto p-4 flex flex-col items-center justify-center relative z-10 pt-8 md:pt-12">
        <div className="mb-8">
          <TokenLogo size="large" />
        </div>

        <div className="flex flex-col sm:flex-row gap-3">
          <ConnectWalletButton />
          <ViewTaxRewards />
          <ViewNFTStatus />
        </div>
      </header>

      <main>
        <HeroSection content={content.hero} />
        <FeaturesSection features={content.features} />
        <RoadmapSection phases={content.roadmap} />
        <TokenomicsSection tokenomics={content.tokenomics} />
        <AdvantagesSection advantages={content.advantages} />
        <CommunitySection communities={content.communities} />
      </main>

      <footer className="container mx-auto p-4 text-center relative z-10 text-sm md:text-base font-montserrat">
        <p>&copy; 2025 The One Token. All rights reserved.</p>
      </footer>
    </div>
  )
}

function HeroSection({ content }: { content: any }) {
  return (
    <section className="container mx-auto px-4 py-12 md:py-20 text-center relative z-10">
      <motion.div initial={{ opacity: 0, y: 20 }} animate={{ opacity: 1, y: 0 }} transition={{ duration: 0.8 }}>
        <h2 className="text-4xl md:text-6xl font-playfair font-bold mb-4 md:mb-6 tracking-wider text-blue-300">
          {content.title}
        </h2>
        <p className="text-lg md:text-xl mb-6 md:mb-8 max-w-2xl mx-auto text-blue-100 font-montserrat leading-relaxed">
          {content.description}
        </p>
        <BuyTokens />
      </motion.div>
    </section>
  )
}

function AnimatedSection({ children }: { children: React.ReactNode }) {
  const controls = useAnimation()
  const [ref, inView] = useInView()

  useEffect(() => {
    if (inView) {
      controls.start("visible")
    }
  }, [controls, inView])

  return (
    <motion.div
      ref={ref}
      animate={controls}
      initial="hidden"
      transition={{ duration: 0.5 }}
      variants={{
        visible: { opacity: 1, y: 0 },
        hidden: { opacity: 0, y: 20 },
      }}
    >
      {children}
    </motion.div>
  )
}

function FeaturesSection({ features }: { features: any[] }) {
  return (
    <AnimatedSection>
      <section className="container mx-auto px-4 py-12 md:py-20">
        <h2 className="text-3xl md:text-5xl font-playfair font-bold mb-6 md:mb-10 text-center tracking-wide text-blue-300">
          Features
        </h2>
        <div className="grid md:grid-cols-2 gap-6 md:gap-8">
          {features.map((feature, index) => (
            <Card
              key={index}
              className="bg-white/10 border-gray-200 shadow-md backdrop-blur-lg hover:bg-white/20 transition-all duration-300"
            >
              <CardHeader>
                <CardTitle className="text-xl md:text-2xl font-cormorant font-semibold tracking-wide text-blue-200">
                  {feature.title}
                </CardTitle>
              </CardHeader>
              <CardContent className="text-sm md:text-base text-blue-100 font-montserrat">
                <ul className="list-disc pl-5 space-y-2">
                  {feature.items.map((item: string, itemIndex: number) => (
                    <li key={itemIndex}>{item}</li>
                  ))}
                </ul>
              </CardContent>
            </Card>
          ))}
        </div>
      </section>
    </AnimatedSection>
  )
}

function RoadmapSection({ phases }: { phases: any[] }) {
  return (
    <AnimatedSection>
      <section className="container mx-auto px-4 py-12 md:py-20">
        <h2 className="text-3xl md:text-5xl font-playfair font-bold mb-6 md:mb-10 text-center tracking-wide text-blue-300">
          The One Token Roadmap
        </h2>
        <div className="space-y-6 md:space-y-8">
          {phases.map((phase, index) => (
            <Card
              key={index}
              className="bg-white/10 border-gray-200 shadow-md backdrop-blur-lg hover:bg-white/20 transition-all duration-300"
            >
              <CardHeader>
                <CardTitle className="text-xl md:text-2xl font-cormorant font-semibold tracking-wide text-blue-200">
                  {phase.title}
                </CardTitle>
              </CardHeader>
              <CardContent className="text-sm md:text-base text-blue-100 font-montserrat">
                <p>{phase.description}</p>
              </CardContent>
            </Card>
          ))}
        </div>
      </section>
    </AnimatedSection>
  )
}

function TokenomicsSection({ tokenomics }: { tokenomics: any[] }) {
  return (
    <AnimatedSection>
      <section className="container mx-auto px-4 py-12 md:py-20">
        <h2 className="text-3xl md:text-5xl font-playfair font-bold mb-6 md:mb-10 text-center tracking-wide text-blue-300">
          The One Token Tokenomics
        </h2>
        <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-6 md:gap-8">
          {tokenomics.map((item, index) => (
            <Card
              key={index}
              className="bg-white/10 border-gray-200 shadow-md backdrop-blur-lg hover:bg-white/20 transition-all duration-300"
            >
              <CardHeader>
                <CardTitle className="text-xl md:text-2xl font-cormorant font-semibold tracking-wide text-blue-200">
                  {item.title}
                </CardTitle>
              </CardHeader>
              <CardContent className="text-sm md:text-base text-blue-100 font-montserrat">
                <p>{item.description}</p>
              </CardContent>
            </Card>
          ))}
        </div>
      </section>
    </AnimatedSection>
  )
}

function AdvantagesSection({ advantages }: { advantages: any[] }) {
  return (
    <AnimatedSection>
      <section className="container mx-auto px-4 py-12 md:py-20">
        <h2 className="text-3xl md:text-5xl font-playfair font-bold mb-6 md:mb-10 text-center tracking-wide text-blue-300">
          The One Token Advantages
        </h2>
        <div className="space-y-6 md:space-y-8">
          {advantages.map((advantage, index) => (
            <Card
              key={index}
              className="bg-white/10 border-gray-200 shadow-md backdrop-blur-lg hover:bg-white/20 transition-all duration-300"
            >
              <CardHeader>
                <CardTitle className="text-xl md:text-2xl font-cormorant font-semibold tracking-wide text-blue-200">
                  {advantage.title}
                </CardTitle>
              </CardHeader>
              <CardContent className="text-sm md:text-base text-blue-100 font-montserrat">
                <p>{advantage.description}</p>
              </CardContent>
            </Card>
          ))}
        </div>
      </section>
    </AnimatedSection>
  )
}

function CommunitySection({ communities }: { communities: any[] }) {
  return (
    <AnimatedSection>
      <section className="container mx-auto px-4 py-12 md:py-20">
        <h2 className="text-3xl md:text-5xl font-playfair font-bold mb-6 md:mb-10 text-center tracking-wide text-blue-300">
          Join The One Token Community
        </h2>
        <div className="grid sm:grid-cols-2 lg:grid-cols-3 gap-6 md:gap-8">
          {communities.map((community, index) => {
            const IconComponent = iconMap[community.icon] || MessageCircle
            return (
              <a
                key={index}
                href={community.url}
                target="_blank"
                rel="noopener noreferrer"
                className="block transition-transform hover:scale-105"
              >
                <Card className="bg-white/10 border-gray-200 shadow-md backdrop-blur-lg hover:bg-white/20 transition-all duration-300">
                  <CardHeader>
                    <CardTitle className="flex items-center text-lg md:text-2xl font-cormorant font-semibold tracking-wide text-blue-200">
                      <IconComponent className="mr-2 h-5 w-5 md:h-6 md:w-6" />
                      {community.name}
                    </CardTitle>
                  </CardHeader>
                  <CardContent className="text-sm md:text-base text-blue-100 font-montserrat">
                    <p>{community.description}</p>
                  </CardContent>
                </Card>
              </a>
            )
          })}
        </div>
      </section>
    </AnimatedSection>
  )
}

